==> apache-servicecomb-java-chassis-distribution-2.2.0-src.zip: apache-servicecomb-java-chassis-distribution-2.2.0-src/foundations/foundation-registry/src/main/java/org/apache/servicecomb/registry/cache/InstanceCacheManagerNew.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.registry.cache;

import org.apache.servicecomb.foundation.common.cache.VersionedCache;
import org.apache.servicecomb.registry.consumer.AppManager;

public class InstanceCacheManagerNew implements InstanceCacheManager {
  private AppManager appManager;

  public InstanceCacheManagerNew(AppManager appManager) {
    this.appManager = appManager;
  }

  @Override
  public InstanceCache getOrCreate(String appId, String microserviceName, String microserviceVersionRule) {
    return appManager.getOrCreateMicroserviceVersionRule(appId, microserviceName, microserviceVersionRule)
        .getInstanceCache();
  }

  @Override
  public VersionedCache getOrCreateVersionedCache(String appId, String microserviceName,
      String microserviceVersionRule) {
    return appManager.getOrCreateMicroserviceVersionRule(appId, microserviceName, microserviceVersionRule)
        .getVersionedCache();
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.30-src.zip: apache-servicecomb-java-chassis-distribution-2.8.30-src/foundations/foundation-registry/src/main/java/org/apache/servicecomb/registry/cache/InstanceCacheManagerNew.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.registry.cache;

import org.apache.servicecomb.foundation.common.cache.VersionedCache;
import org.apache.servicecomb.registry.consumer.AppManager;

public class InstanceCacheManagerNew implements InstanceCacheManager {
  private final AppManager appManager;

  public InstanceCacheManagerNew(AppManager appManager) {
    this.appManager = appManager;
  }

  @Override
  public InstanceCache getOrCreate(String appId, String microserviceName, String microserviceVersionRule) {
    return appManager.getOrCreateMicroserviceVersionRule(appId, microserviceName, microserviceVersionRule)
        .getInstanceCache();
  }

  @Override
  public VersionedCache getOrCreateVersionedCache(String appId, String microserviceName,
      String microserviceVersionRule) {
    return appManager.getOrCreateMicroserviceVersionRule(appId, microserviceName, microserviceVersionRule)
        .getVersionedCache();
  }
}
